<?php
/**
 * Aurora Heatmap Installer Class
 *
 * @package aurora-heatmap
 * @copyright 2019-2024 R3098 <info@seous.info>
 * @version 0.1.10
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Aurora_Heatmap_Installer
 *
 * phpcs:disable WordPress.WP.I18n.NonSingularStringLiteralDomain
 */
class Aurora_Heatmap_Installer {

	const SLUG = 'aurora-heatmap-premium';

	const DOMAIN = 'aurora-heatmap-premium-installer';

	const VERSION = '0.1.10';

	/**
	 * Freemius object
	 *
	 * @var object Freemius.
	 */
	protected $freemius;

	/**
	 * Singleton object
	 *
	 * @var object
	 */
	private static $self;

	/**
	 * Get instance
	 */
	public static function get_instance() {
		if ( ! self::$self ) {
			self::$self = new self();
		}

		return self::$self;
	}

	/**
	 * Constructor
	 */
	protected function __construct() {
		$this->freemius = aurora_heatmap_fs();
		add_action( 'admin_init', array( &$this, 'admin_init' ) );
		add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
	}

	/**
	 * Callback for admin_init.
	 */
	public function admin_init() {
		if ( filter_input( INPUT_GET, 'aurora-heatmap-delete-account' ) ) {
			// Avoid to display Freemius Notice errors.
			error_reporting( E_ALL ^ E_NOTICE ^ E_USER_NOTICE ); // phpcs:ignore WordPress
			$this->freemius->delete_account_event();
			fs_redirect( $this->freemius->get_activation_url() );
			exit;
		}
	}

	/**
	 * Callback for register_action_hook
	 */
	public static function activation() {
		// Do nothing.
		return 0;
	}

	/**
	 * Callback for register_deactivation_hook
	 */
	public static function deactivation() {
		// Do nothing.
		return 0;
	}

	/**
	 * Action hook for admin_menu
	 */
	public function admin_menu() {
		add_options_page(
			__( 'Aurora Heatmap', $this::DOMAIN ),
			__( 'Aurora Heatmap', $this::DOMAIN ),
			'manage_options',
			$this::SLUG,
			array( &$this, 'admin_options_page' )
		);
	}

	/**
	 * Translation without poedit pickup
	 *
	 * @param string $text   Text.
	 * @param string $domain Domain.
	 * @return string
	 */
	private function t( $text, $domain = 'default' ) {
		return esc_html__( $text, $domain ); // phpcs:ignore WordPress.WP.I18n.NonSingularStringLiteralText
	}

	/**
	 * Callback for admin_options_page
	 */
	public function admin_options_page() {
		$is_registered = $this->freemius->is_registered();
		$is_paying     = $this->freemius->is_paying();
		?>
<style type="text/css">
.ahmi-done { opacity: 0.6; }
.ahmi-next { opacity: 0.4; }
.ahmi-box { background: rgba(0, 0, 0, 0.08); padding: 0.15em 1em; margin: 1em 0; }
details { margin: 1em 0; }
summary { cursor: pointer; list-style: none; font-weight: bold; }
summary:focus { outline: unset; }
summary::-webkit-details-marker { display: none; }
details[open]>summary>:first-child::before { content: '\f140'; }
b { font-weight: 700; }
details>div { border-radius: .5em; border: 0.15em solid #ccc; margin: 0.5em 0; padding: 0.5em; }
</style>
		<div class="wrap">
			<h2><?php esc_html_e( 'Aurora Heatmap (Installer)', $this::DOMAIN ); ?></h2>

			<hr>
			<h3><?php esc_html_e( 'Important matter', $this::DOMAIN ); ?></h3>
			<ol style="list-style-type: disc">
				<li>
				<?php
					printf(
						// translators: %s: Premium version.
						__( '<b>%s</b> can be used by updating the plugin after the license agreement.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
						esc_html__( 'Aurora Heatmap premium version', $this::DOMAIN )
					);
				?>
				</li>
				<li>
				<?php
					esc_html_e( 'This plugin is an installer that makes it easy to obtain a license agreement and obtain the plugin itself.', $this::DOMAIN );
				?>
				</li>
				<li>
				<?php
					printf(
						// translators: %s: plugin URL.
						__( 'If you want the <b>free version</b> of the Aurora Heatmap, please <b>deactivate</b> / <b>delete</b> this installer and use the <a href="%s">free version</a>.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
						esc_attr__( 'https://wordpress.org/plugins/aurora-heatmap/', $this::DOMAIN )
					);
				?>
				</li>
			</ol>

			<hr>
			<h3><?php esc_html_e( 'Installation procedure', $this::DOMAIN ); ?></h3>
			<div class="ahmi-box">
				<ol style="list-style-type: diesc">
					<li><b><?php esc_html_e( 'User registration', $this::DOMAIN ); ?></b> ... <?php _e( 'Partner with <a href="https://freemius.com/">freemius.com</a>.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
					<li><b><?php esc_html_e( 'License agreement', $this::DOMAIN ); ?></b> ... <?php esc_html_e( 'Please pay with your preferred plan.', $this::DOMAIN ); ?></li>
					<li><b><?php esc_html_e( 'Update plugin', $this::DOMAIN ); ?></b> ... <?php esc_html_e( 'Update the plugin from this installer to the premium version.', $this::DOMAIN ); ?></li>
				</ol>
			</div>
			<?php
				$this->step1_registeration( $is_registered, $is_paying );
				$this->step2_payment( $is_registered, $is_paying );
				$this->step3_update( $is_registered, $is_paying );
			?>

			<hr>
			<div style='font-weight: bold; font-size: larger; text-align: right; color: #aaa; text-shadow: 1px 1px 1px #ffffff;'><?php esc_html_e( 'Aurora Heatmap' ); ?></div>
		</div>
		<?php
	}

	/**
	 * STEP1. User registration
	 *
	 * @param bool $is_registered Is registered.
	 * @param bool $is_paying     Is paying.
	 */
	private function step1_registeration( $is_registered, $is_paying ) {
		$user       = wp_get_current_user();
		$fs_user    = $this->freemius->get_user();
		$is_pending = $this->freemius->is_pending_activation();
		$details    = $is_registered ? '' : ' open';
		$summary    = $is_registered ? 'ahmi-done' : '';

		?>
		<details<?php echo esc_attr( $details ); ?>>
			<summary class="<?php echo esc_attr( $summary ); ?>">
				<span class="dashicons dashicons-arrow-right"></span>
				1. <?php esc_html_e( 'User registration', $this::DOMAIN ); ?>
				<?php if ( $is_registered ) : ?>
					<span class="dashicons dashicons-yes-alt"></span>
				<?php endif; ?>
			</summary>
			<div>

			<?php if ( ! $is_registered ) : ?>
				<p><?php _e( 'To issue a license, register as a free plan at <a href="https://freemius.com/">freemius.com</a>.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></p>
				<ol style="list-style-type: disc;">
					<li>
					<?php
						printf(
							// translators: %1$s: Profile %2$s: email address %3$s: email label.
							__( '<a href="profile.php">%1$s</a> email address <b><a href="mailto:%2$s">%3$s</a></b> will be used for user registration.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
							$this->t( 'Your Profile' ), // phpcs:ignore WordPress.Security.EscapeOutput
							esc_attr( $user->user_email ),
							esc_html( $user->user_email )
						);
					?>
					</li>
					<li><?php esc_html_e( 'Please note that we cannot provide support if your mail address is not correct.', $this::DOMAIN ); ?></li>
				</ol>
			<?php else : ?>
				<table class="widefat">
					<tr>
						<th><b>User ID</b></th>
						<td><?php echo esc_html( $fs_user->id ); ?></td></tr>
					<tr>
						<th><b>Name</b></th>
						<td><?php echo esc_html( "{$fs_user->first} {$fs_user->last}" ); ?></td>
					</tr>
					<tr>
						<th><b>Email</b></th>
						<td><?php echo esc_html( $fs_user->email ); ?></td>
					</tr>
				</table>
			<?php endif; ?>

			<?php if ( ! $is_registered && ! $is_pending ) : ?>
				<h4><?php esc_html_e( 'User registration procedure', $this::DOMAIN ); ?></h4>
				<ol>
					<li>
					<?php
						printf(
							// translators: %s: Installed Plugins.
							__( 'Click the <b>[ Opt In ]</b> link under <a href="plugins.php?s=aurora-heatmap-premium-installer">%s</a>.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
							esc_html( $this->t( 'Installed Plugins' ) )
						);
					?>
					</li>
					<li><?php _e( 'Click the <b>[ Activate Free Version ]</b> link and click the <b>[ Allow &amp; Continue ]</b> button on the next screen to register the user.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
				</ol>
			<?php endif; ?>

			<?php if ( $is_pending ) : // For pending email activation. ?>
				<h4><span class="dashicons dashicons-info"></span> <?php esc_html_e( 'If the following notification appears at the top of the page', $this::DOMAIN ); ?></h4>
				<div style="margin: 4px 0 15px; color: green; border-left: 4px solid #46b450; background: #fff; box-shadow: 0 1px 1px 0 rgba(0, 0, 0, .1); padding: 1px 12px;">
					<div style="margin: .5em 0; padding: 2px;"><b>Thanks!</b> You should receive an activation email for <b>Aurora Heatmap (Installer)</b> to your mailbox at <b><?php echo esc_html( $user->user_email ); ?></b>. Please make sure you click the activation button in that email to complete the install.</div>
				</div>
				<p>
				<?php
					_e( 'An authentication email has been sent for confirmation. Click the <b>[ Activate Plugin ]</b> button in the email to complete.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput
				?>
				</p>
			<?php endif; ?>

			<h4><span class="dashicons dashicons-info"></span> <?php esc_html_e( 'If you can\'t receive authentication email', $this::DOMAIN ); ?></h4>
			<p>
			<?php
				printf(
					// translators: %s: Your Profile.
					__( 'Change the email address of <a href="profile.php">%s</a> and restart the user registration with the following button.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
					esc_html( $this->t( 'Your Profile' ) )
				);
			?>
			</p>
			<div><a href="options-general.php?page=aurora-heatmap-premium&aurora-heatmap-delete-account=1" class="button button-primary"><?php esc_html_e( 'Restart the user registration', $this::DOMAIN ); ?></a></div>

			</div>
		</details>
		<?php
	}

	/**
	 * STEP2. payment
	 *
	 * @param bool $is_registered Is registered.
	 * @param bool $is_paying     Is paying.
	 */
	private function step2_payment( $is_registered, $is_paying ) {
		$details = $is_paying ? '' : ' open';
		$summary = $is_paying ? 'ahmi-done' : '';
		?>

		<details<?php echo esc_attr( $details ); ?>>
			<summary class="<?php echo esc_attr( $summary ); ?>">
				<span class="dashicons dashicons-arrow-right"></span>
				2. <?php esc_html_e( 'License agreement', $this::DOMAIN ); ?>
				<?php if ( $is_paying ) : ?>
					<span class="dashicons dashicons-yes-alt"></span>
				<?php endif; ?>
			</summary>
			<div>

				<p>
				<?php
					printf(
						// translators: %s: Upgrade.
						__( 'License contract for standard plan from <a href="options-general.php?page=aurora-heatmap-premium-pricing">%s</a>.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
						esc_html( $this->t( 'Upgrade', 'freemius' ) )
					);
				?>
				</p>
				<ol>
					<li><?php _e( 'Specify the number of standard plan licenses and click <b>[ UPGRADE NOW ]</b>.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
					<li><?php _e( 'Select <b>[ Monthly ]</b> or <b>[ Annually ]</b>.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
					<li><?php esc_html_e( 'Select your credit card or PayPal payment method and enter your information.', $this::DOMAIN ); ?></li>
					<li><?php _e( 'Click the <b>[ Review Order ]</b> button.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
					<li><?php _e( 'A confirmation screen will appear. Click the <b>[ Pay &amp; Subscribe ]</b> button to settle the payment.', $this::DOMAIN ); // phpcs:ignore WordPress.Security.EscapeOutput ?></li>
				</ol>
			</div>
		</details>
		<?php
	}

	/**
	 * STEP2. Update
	 *
	 * @param bool $is_registered Is registered.
	 * @param bool $is_paying     Is paying.
	 */
	private function step3_update( $is_registered, $is_paying ) {
		$details = $is_paying ? ' open' : '';
		$summary = $is_paying ? '' : 'ahmi-next';
		?>

		<details<?php echo esc_attr( $details ); ?>>
			<summary class="<?php echo esc_attr( $summary ); ?>">
				<span class="dashicons dashicons-arrow-right"></span>
				3. <?php esc_html_e( 'Update plugin', $this::DOMAIN ); ?>
			</summary>
			<div>
				<p>
				<?php
					printf(
						// translators: %1$s: Update %2$s: Installer %3$s: premium version.
						__( '<a href="update-core.php">%1$s</a> <b>%2$s</b> to the latest <b>%3$s</b>.', $this::DOMAIN ), // phpcs:ignore WordPress.Security.EscapeOutput
						$this->t( 'Update' ), // phpcs:ignore WordPress.Security.EscapeOutput
						esc_html__( 'Aurora Heatmap (Installer)', $this::DOMAIN ),
						esc_html__( 'Aurora Heatmap premium version', $this::DOMAIN )
					);
				?>
				</p>
			</div>
		</details>
		<?php
	}
}

/* vim: set ts=4 sw=4 sts=4 noet: */
